!----------------------------------------------------------------------
! module contenant deux subroutines de sorties au format vtk
!   -> sortie_obstacle : pour visualiser l'obstacle
!   -> sorties_vtk : pour les valeurs de la densite, du champ de vitesse
!                    du champ de vorticite, et de l'obstacle           
module mod_sorties

  use mod_precision

  implicit none

contains

  subroutine sortie_obstacle(x,y,obst)

    integer :: i,j,imax,jmax
    real(pr), dimension(:), allocatable, intent(in) :: x,y
    integer, dimension(:,:), intent(in) :: obst

    imax = size(obst,1)
    jmax = size(obst,2)

    open(unit=1,file='obstacle.vtk')
    write(1,'(1A26)') '# vtk DataFile Version 2.0'
    write(1,'(1A8)') 'obstacle'
    write(1,'(1A5)') 'ASCII'
    write(1,'(1A24)') 'DATASET RECTILINEAR_GRID'
    write(1,'(1A10,3I4)') 'DIMENSIONS ',imax,jmax,1
    write(1,*) 'X_COORDINATES',imax,' double'
    do i=1,imax
       write(1,*) x(i)
    end do
    write(1,*) 'Y_COORDINATES',jmax,' double'
    do j=1,jmax
       write(1,*) y(j)
    end do
    write(1,*) 'Z_COORDINATES',1,' double'
    write(1,*) 0.0_pr

    write(1,*) 'POINT_DATA',imax*jmax
    write(1,*) 'SCALARS obstacle double'
    write(1,*) 'LOOKUP_TABLE default'
    do j=1,jmax
       do i=1,imax
          write(1,*) obst(i,j)
       end do
    end do

    close(1)

  end subroutine sortie_obstacle

  subroutine sorties_vtk(x,y,rho,ux,uy,obst,fich)

    integer :: i,j,imax,jmax
    character(len=*), intent(in) :: fich
    real(pr), dimension(:), allocatable, intent(in) :: x,y
    real(pr), dimension(:,:), intent(in) :: rho,ux,uy
    integer, dimension(:,:), intent(in) :: obst

    real(pr) :: vort, dyux, dxuy


    imax = size(rho,1)
    jmax = size(rho,2)

    open(unit=1,file=trim(adjustl(fich)))
    write(1,'(1A26)') '# vtk DataFile Version 2.0'
    write(1,'(1A16)') 'champ de vitesse'
    write(1,'(1A5)') 'ASCII'
    write(1,'(1A24)') 'DATASET RECTILINEAR_GRID'
    write(1,'(1A10,3I4)') 'DIMENSIONS ',imax,jmax,1
    write(1,*) 'X_COORDINATES',imax,' double'
    do i=1,imax
       write(1,*) x(i)
    end do
    write(1,*) 'Y_COORDINATES',jmax,' double'
    do j=1,jmax
       write(1,*) y(j)
    end do
    write(1,*) 'Z_COORDINATES',1,' double'
    write(1,*) 0.0_pr

    write(1,*) 'POINT_DATA',imax*jmax
    write(1,*) 'SCALARS rho double'
    write(1,*) 'LOOKUP_TABLE default'
    do j=1,jmax
       do i=1,imax
          write(1,*) rho(i,j)
       end do
    end do

    write(1,*) 'SCALARS vort double'
    write(1,*) 'LOOKUP_TABLE default'
    do j=1,jmax
       do i=1,imax
          if (j==1.or.j==jmax) then
             dyux = 0._pr
          else
             dyux = (ux(i,j+1) - ux(i,j-1))/2._pr
          end if
          if (i==1.or.i==imax) then
             dxuy = 0._pr
          else
             dxuy = (uy(i+1,j) - uy(i-1,j))/2._pr                
          end if
          vort = dyux - dxuy
          write(1,*) vort
       end do
    end do

    write(1,*) 'SCALARS obstacle double'
    write(1,*) 'LOOKUP_TABLE default'
    do j=1,jmax
       do i=1,imax
          write(1,*) obst(i,j)
       end do
    end do


    write(1,*) 'VECTORS u double'
    do j=1,jmax
       do i=1,imax
          write(1,*) ux(i,j),uy(i,j),0.0_pr
       end do
    end do

    close(1)

  end subroutine sorties_vtk

end module mod_sorties






